@@ -12,13 +12,8 @@ function (object, resp.patterns = NULL, method = c("EB", "MI"), B = 5, ...) {
         warning("object does not have an estimate of the Hessian; the 'EB' method is used instead.\n")
         method <- "EB"
     }
-    Obs <- if (!is.null(resp.patterns)) {
-        ind <- match(apply(X, 1, paste, collapse = ""), apply(object$patterns$X, 1, paste, collapse = ""))
-        obs <- rep(0, nrow(X))
-        obs[!is.na(ind)] <- object$patterns$obs[ind[!is.na(ind)]]
-        obs
-    } else 
-        object$patterns$obs
+    vals <- lapply(betas, function(x) seq(1, length(x) - 1)) 
+    Obs <- observedFreqs(object, X, vals)
     res <- data.frame(X, Obs = Obs, Exp = fits[, ncol(fits)])
     names(res)[1:p] <- names(betas)
     environment(fscores.g) <- environment()
